==> CustomGS-1.2.tar.gz: CustomGS/lang/en_US.php <==
<?php
$lang['moddescription'] = 'A module to extend the Global Settings with some customized parameters. You can define an unlimited number of fields which can be used as smarty-variable in templates or pages.';

$lang['postinstall'] = 'CustomGS module successfully installed!';
$lang['uninstall_confirm'] = 'Do your really want to uninstall the CustomGS module?';
$lang['postuninstall'] = 'CustomGS module successfull uninstalled!';


/**
 * Admin General Tab
 */
$lang['title_general'] = 'General';


/**
 * Admin Fielddefs Tab
 */
$lang['title_fielddefs'] = 'Field Definitions';
$lang['smartyvar'] = 'Smarty variable';
$lang['textfield'] = 'Textfield';
$lang['pulldown'] = 'Pulldown';
$lang['checkbox'] = 'Checkbox';
$lang['radiobuttons'] = 'Radiobutton group';
$lang['datepicker'] = 'Datepicker';
$lang['datetimepicker'] = 'DateTimepicker';
$lang['timepicker'] = 'Timepicker';
$lang['textarea'] = 'Text Area';
$lang['wysiwyg'] = 'WYSIWYG';
$lang['button'] = 'Button';
$lang['maxlength'] = 'Maximum Length';
$lang['properties'] = 'Properties';
$lang['properties_help1'] = 'Enter the choice values, each one on a new line. Also supports Value|OptionName pairs and/or Smarty tags';
$lang['parsesmarty'] = 'Parse data by Smarty';
$lang['clearcache_help'] = 'Automatically clear site cache after changing this setting. USE WITH CAUTION!';
$lang['fielddefadded'] = 'Field Definition is added';
$lang['fielddefsupdated'] = 'Field Definition list is updated';


/**
 * Admin Options Tab
 */ 
$lang['title_custom_modulename'] = 'Custom Modulename';
$lang['help_custom_modulename'] = 'You can change the Modulename here as you wish. It will be used as the title on the module admin pages and as menu text.';

$lang['title_admin_section'] = 'Admin Section';
$lang['help_admin_section'] = 'Choose the Admin Section (or top-level Admin Menu) this module belongs to.';

/**
 * Saving
 */ 
$lang['settingssaved'] = 'Settings successfully saved!';


/**
 * Events
 */
$lang['event_info_OnSettingChange'] = 'Event triggered when a setting is edited.';
$lang['event_help_OnSettingChange'] = '<p>Event triggered when a setting is edited.</p>
<h4>Parameters</h4>
<ul>
<li>fieldid</li>
<li>name</li>
<li>alias</li>
<li>value</li>
</ul>
';
?>

==> CustomGS-1.3.tar.gz: CustomGS/lang/en_US.php <==
<?php
$lang['moddescription'] = 'A module to extend the Global Settings with some customized parameters. You can define an unlimited number of fields which can be used as smarty-variable in templates or pages.';

$lang['postinstall'] = 'CustomGS module successfully installed!';
$lang['uninstall_confirm'] = 'Do your really want to uninstall the CustomGS module?';
$lang['postuninstall'] = 'CustomGS module successfull uninstalled!';


/**
 * Admin General Tab
 */
$lang['now'] = 'now';
$lang['title_general'] = 'General';
$lang['choosetime'] = 'Choose time';
$lang['time'] = 'time';
$lang[''] = '';


/**
 * Admin Fielddefs Tab
 */
$lang['title_fielddefs'] = 'Field Definitions';
$lang['smartyvar'] = 'Smarty variable';
$lang['textfield'] = 'Textfield';
$lang['pulldown'] = 'Pulldown';
$lang['checkbox'] = 'Checkbox';
$lang['radiobuttons'] = 'Radiobutton group';
$lang['datepicker'] = 'Datepicker';
$lang['datetimepicker'] = 'DateTimepicker';
$lang['timepicker'] = 'Timepicker';
$lang['textarea'] = 'Text Area';
$lang['wysiwyg'] = 'WYSIWYG';
$lang['button'] = 'Button';
$lang['maxlength'] = 'Maximum Length';
$lang['properties'] = 'Properties';
$lang['properties_help1'] = 'Enter the choice values, each one on a new line. Also supports Value|OptionName pairs and/or Smarty tags';
$lang['parsesmarty'] = 'Parse data by Smarty';
$lang['clearstylesheetcache'] = 'Clear stylesheet cache';
$lang['clearstylesheetcache_help'] = 'Automatically clear stylesheet cache after changing this setting. USE WITH CAUTION!';
$lang['fielddefadded'] = 'Field Definition is added';
$lang['fielddefsupdated'] = 'Field Definition list is updated';


/**
 * Admin Options Tab
 */ 
$lang['title_custom_modulename'] = 'Custom Modulename';
$lang['help_custom_modulename'] = 'You can change the Modulename here as you wish. It will be used as the title on the module admin pages and as menu text.';

$lang['title_admin_section'] = 'Admin Section';
$lang['help_admin_section'] = 'Choose the Admin Section (or top-level Admin Menu) this module belongs to.';

/**
 * Saving
 */ 
$lang['settingssaved'] = 'Settings successfully saved!';


/**
 * Events
 */
$lang['event_info_OnSettingChange'] = 'Event triggered when a setting is edited.';
$lang['event_help_OnSettingChange'] = '<p>Event triggered when a setting is edited.</p>
<h4>Parameters</h4>
<ul>
<li>fieldid</li>
<li>name</li>
<li>alias</li>
<li>value</li>
<li>clearcache</li>
</ul>
';
?>
